pub struct Runner<'a, T: Library> { /* private fields */ }Expand description
The main build script runner. See Self::run for more details.
Implementations
Sourceimpl<'a, T: Library> Runner<'a, T>
impl<'a, T: Library> Runner<'a, T>
Sourcepub fn new(
version: &'a str,
ni_version: &'a str,
libraries: Vec<T>,
header_contents: &'a str,
allowlist: &'a str,
lib_list: &'a [&'a str],
output_directory: &'a Path,
clang_args: String,
) -> Self
pub fn new( version: &'a str, ni_version: &'a str, libraries: Vec<T>, header_contents: &'a str, allowlist: &'a str, lib_list: &'a [&'a str], output_directory: &'a Path, clang_args: String, ) -> Self
Create a new Runner.
Sourcepub async fn download_libraries(&mut self) -> Result<()>
pub async fn download_libraries(&mut self) -> Result<()>
Download the libraries from the FRC Maven JFrog repository. This method downloads to {output_directory}/raw/. If this function succeeds, every FRC-related library should be available (unzipped) in this directory.
Sourcepub async fn install_libraries(&mut self) -> Result<()>
pub async fn install_libraries(&mut self) -> Result<()>
Ready the libraries for linking. While in theory this step should also move them to a separate directory, it’s much easier to keep them in their existing directory and make changes on that.
This method will set all .so files to executable, remove the .debug files, and rename malformed files (e.g. libX.so.22.0.0 to libX.so).
Sourcepub fn link_libraries(&mut self) -> Result<()>
pub fn link_libraries(&mut self) -> Result<()>
Ask Cargo to link to the dynamic libraries.